# comanage_nacha 
[![Build Status](https://travis-ci.org/DisruptiveLabs/comanage_nacha.svg?branch=master)](https://travis-ci.org/DisruptiveLabs/comanage_nacha)
[![Coverage Status](https://coveralls.io/repos/github/DisruptiveLabs/comanage_nacha/badge.svg?branch=master)](https://coveralls.io/github/DisruptiveLabs/comanage_nacha?branch=master)
[![PyPI version](https://badge.fury.io/py/comanage_nacha.svg)](https://badge.fury.io/py/comanage_nacha)

A simple NACHA parser/builder/verification tool

```bash
$ python setup.py test
```

For examples of usage, currently see the tests. Documentation forthcoming

You can run tests in multiple versions of python using tox